==> chronicle-wire-2.17.46-sources.jar: net/openhft/chronicle/wire/MessageHistory.java <==
/*
 * Copyright 2016 higherfrequencytrading.com
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.openhft.chronicle.wire;

/*
 * Created by Peter Lawrey on 27/03/16.
 */
public interface MessageHistory extends Marshallable {
    /**
     * Get the MessageHistory to update it or read it.
     *
     * @return the MessageHistory for the current Excerpt.
     */
    static MessageHistory get() {
        return VanillaMessageHistory.getThreadLocal();
    }

    /**
     * You only need to call this if you wish to override it's behaviour.
     *
     * @param md to change to the default implementation for this thread.
     */
    static void set(MessageHistory md) {
        VanillaMessageHistory.setThreadLocal(md);
    }

    int timings();

    long timing(int n);

    int sources();

    int sourceId(int n);

    boolean sourceIdsEndsWith(int[] sourceIds);

    long sourceIndex(int n);

    /**
     * clear all data
     */
    void reset();

    /**
     * reset for a given source prior to reading a new message in
     */
    void reset(int sourceId, long sourceIndex);

    int lastSourceId();

    long lastSourceIndex();
}

==> chronicle-wire-2.20.22-sources.jar: net/openhft/chronicle/wire/MessageHistory.java <==
/*
 * Copyright 2016-2020 Chronicle Software
 *
 * https://chronicle.software
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.openhft.chronicle.wire;

import net.openhft.chronicle.bytes.MethodReader;
import net.openhft.chronicle.core.annotation.UsedViaReflection;

public interface MessageHistory extends Marshallable {
    /**
     * Get the MessageHistory to update it or read it.
     *
     * @return the MessageHistory for the current Excerpt.
     */
    static MessageHistory get() {
        return VanillaMessageHistory.getThreadLocal();
    }

    /**
     * You only need to call this if you wish to override it's behaviour.
     *
     * @param md to change to the default implementation for this thread.
     */
    static void set(MessageHistory md) {
        VanillaMessageHistory.setThreadLocal(md);
    }

    @UsedViaReflection
    static void writeHistory(DocumentContext dc) {
        Wire wire = dc.wire();
        if (wire.bytes().readRemaining() == 0) // only add to the start of a message. i.e. for chained calls.
            wire.writeEventName(MethodReader.HISTORY)
                    .marshallable(get());
    }

    int timings();

    long timing(int n);

    int sources();

    int sourceId(int n);

    boolean sourceIdsEndsWith(int[] sourceIds);

    long sourceIndex(int n);

    /**
     * clear all data
     */
    void reset();

    /**
     * reset for a given source prior to reading a new message in
     */
    void reset(int sourceId, long sourceIndex);

    int lastSourceId();

    long lastSourceIndex();
}
